pype32.consts

Package pype32 :: Module consts |
[hide private]
[frames] | no frames]

# Module consts

source code

Common definitions.

Variables | [hide private]
| __revision__ = ``'``$Id$``'``
| MZ_SIGNATURE = `23117`
| PE_SIGNATURE = `17744`
| SECTION_HEADER_LENGTH = `40`
| INTEL386 = `332`
| COMMON_CHARACTERISTICS = `258`
| PE32 = `267`
| PE64 = `523`
| WINDOWSGUI = `2`
| TERMINAL_SERVER_AWARE = `32768`
| IMAGE_NUMBEROF_DIRECTORY_ENTRIES = `16`
| EXPORT_DIRECTORY = `0`
| IMPORT_DIRECTORY = `1`
| RESOURCE_DIRECTORY = `2`
| EXCEPTION_DIRECTORY = `3`
| SECURITY_DIRECTORY = `4`
| RELOCATION_DIRECTORY = `5`
| DEBUG_DIRECTORY = `6`
| ARCHITECTURE_DIRECTORY = `7`
| TLS_DIRECTORY = `9`
| CONFIGURATION_DIRECTORY = `10`
| BOUND_IMPORT_DIRECTORY = `11`
| IAT_DIRECTORY = `12`
| DELAY_IMPORT_DIRECTORY = `13`
| NET_METADATA_DIRECTORY = `14`
| RESERVED_DIRECTORY = `15`
| IMAGE_DOS_HEADER = `0`
| IMAGE_NT_HEADERS = `1`
| IMAGE_FILE_HEADER = `2`
| IMAGE_OPTIONAL_HEADER = `3`
| IMAGE_SECTION_HEADER = `4`
| IMAGE_DATA_DIRECTORY = `5`
| IMAGE_IMPORT_DESCRIPTOR = `6`
| NET_DIRECTORY = `7`
| NET_METADATA_HEADER = `8`
| IMAGE_COR20_HEADER = `9`
| NET_METADATA_STREAM_ENTRY = `10`
| NET_METADATA_STREAMS = `11`
| NET_METADATA_TABLE_HEADER = `12`
| NET_METADATA_TABLES = `13`
| IMAGE_DEBUG_DIRECTORY = `14`
| IMAGE_DEBUG_DIRECTORIES = `15`
| IMAGE_IMPORT_DESCRIPTOR_ENTRY = `16`
| IMPORT_ADDRESS_TABLE_ENTRY = `17`
| IMPORT_ADDRESS_TABLE = `18`
| IID_METADATA = `19`
| EXPORT_TABLE_ENTRY = `20`
| IMAGE_BASE_RELOCATION_ENTRY = `21`
| IMAGE_BOUND_IMPORT_DESCRIPTOR_ENTRY = `22`
| IMAGE_BOUND_FORWARDER_REF_ENTRY = `23`
| NET_TABLES = `24`
| IMAGE_OPTIONAL_HEADER64 = `25`
| IMPORT_ADDRESS_TABLE_ENTRY64 = `27`
| TLS_DIRECTORY64 = `28`
| SIZEOF_IMAGE_DEBUG_ENTRY32 = `28`
| SIZEOF_IMAGE_IMPORT_ENTRY32 = `20`
| SIZEOF_IMAGE_BOUND_IMPORT_ENTRY32 = `8`
| SIZEOF_IMAGE_BOUND_FORWARDER_REF_ENTRY32 = `8`
| DEFAULT_FILE_ALIGNMENT = `512`
| DEFAULT_PAGE_SIZE = `4096`
| IMAGE_ORDINAL_FLAG = `2147483648`
| IMAGE_ORDINAL_FLAG64 = `9223372036854775808`
| OPTIONAL_HEADER_MAGIC_PE = `267`
| OPTIONAL_HEADER_MAGIC_PE_PLUS = `523`
| IMAGE_FILE_RELOCS_STRIPPED = `1`
| IMAGE_FILE_EXECUTABLE_IMAGE = `2`
| IMAGE_FILE_LINE_NUMS_STRIPPED = `4`
| IMAGE_FILE_LOCAL_SYMS_STRIPPED = `8`
| IMAGE_FILE_AGGRESIVE_WS_TRIM = `16`
| IMAGE_FILE_LARGE_ADDRESS_AWARE = `32`
| IMAGE_FILE_16BIT_MACHINE = `64`
| IMAGE_FILE_BYTES_REVERSED_LO = `128`
| IMAGE_FILE_32BIT_MACHINE = `256`
| IMAGE_FILE_DEBUG_STRIPPED = `512`
| IMAGE_FILE_REMOVABLE_RUN_FROM_SWAP = `1024`
| IMAGE_FILE_NET_RUN_FROM_SWAP = `2048`
| IMAGE_FILE_SYSTEM = `4096`
| IMAGE_FILE_DLL = `8192`
| IMAGE_FILE_UP_SYSTEM_ONLY = `16384`
| IMAGE_FILE_BYTES_REVERSED_HI = `32768`
| IMAGE_SCN_CNT_CODE = `32`
| IMAGE_SCN_CNT_INITIALIZED_DATA = `64`
| IMAGE_SCN_CNT_UNINITIALIZED_DATA = `128`
| IMAGE_SCN_LNK_OTHER = `256`
| IMAGE_SCN_LNK_INFO = `512`
| IMAGE_SCN_LNK_REMOVE = `2048`
| IMAGE_SCN_LNK_COMDAT = `4096`
| IMAGE_SCN_MEM_FARDATA = `32768`
| IMAGE_SCN_MEM_PURGEABLE = `131072`
| IMAGE_SCN_MEM_16BIT = `131072`
| IMAGE_SCN_MEM_LOCKED = `262144`
| IMAGE_SCN_MEM_PRELOAD = `524288`
| IMAGE_SCN_ALIGN_1BYTES = `1048576`
| IMAGE_SCN_ALIGN_2BYTES = `2097152`
| IMAGE_SCN_ALIGN_4BYTES = `3145728`
| IMAGE_SCN_ALIGN_8BYTES = `4194304`
| IMAGE_SCN_ALIGN_16BYTES = `5242880`
| IMAGE_SCN_ALIGN_32BYTES = `6291456`
| IMAGE_SCN_ALIGN_64BYTES = `7340032`
| IMAGE_SCN_ALIGN_128BYTES = `8388608`
| IMAGE_SCN_ALIGN_256BYTES = `9437184`
| IMAGE_SCN_ALIGN_512BYTES = `10485760`
| IMAGE_SCN_ALIGN_1024BYTES = `11534336`
| IMAGE_SCN_ALIGN_2048BYTES = `12582912`
| IMAGE_SCN_ALIGN_4096BYTES = `13631488`
| IMAGE_SCN_ALIGN_8192BYTES = `14680064`
| IMAGE_SCN_ALIGN_MASK = `15728640`
| IMAGE_SCN_LNK_NRELOC_OVFL = `16777216`
| IMAGE_SCN_MEM_DISCARDABLE = `33554432`
| IMAGE_SCN_MEM_NOT_CACHED = `67108864`
| IMAGE_SCN_MEM_NOT_PAGED = `134217728`
| IMAGE_SCN_MEM_SHARED = `268435456`
| IMAGE_SCN_MEM_EXECUTE = `536870912`
| IMAGE_SCN_MEM_READ = `1073741824`
| IMAGE_SCN_MEM_WRITE = `2147483648`
| IMAGE_DEBUG_TYPE_UNKNOWN = `0`
| IMAGE_DEBUG_TYPE_COFF = `1`
| IMAGE_DEBUG_TYPE_CODEVIEW = `2`
| IMAGE_DEBUG_TYPE_FPO = `3`
| IMAGE_DEBUG_TYPE_MISC = `4`
| IMAGE_DEBUG_TYPE_EXCEPTION = `5`
| IMAGE_DEBUG_TYPE_FIXUP = `6`
| IMAGE_DEBUG_TYPE_OMAP_TO_SRC = `7`
| IMAGE_DEBUG_TYPE_OMAP_FROM_SRC = `8`
| IMAGE_DEBUG_TYPE_BORLAND = `9`
| IMAGE_DEBUG_TYPE_RESERVED10 = `10`
| IMAGE_SUBSYSTEM_UNKNOWN = `0`
| IMAGE_SUBSYSTEM_NATIVE = `1`
| IMAGE_SUBSYSTEM_WINDOWS_GUI = `2`
| IMAGE_SUBSYSTEM_WINDOWS_CUI = `3`
| IMAGE_SUBSYSTEM_OS2_CUI = `5`
| IMAGE_SUBSYSTEM_POSIX_CUI = `7`
| IMAGE_SUBSYSTEM_WINDOWS_CE_GUI = `9`
| IMAGE_SUBSYSTEM_EFI_APPLICATION = `10`
| IMAGE_SUBSYSTEM_EFI_BOOT_SERVICE_DRIVER = `11`
| IMAGE_SUBSYSTEM_EFI_RUNTIME_DRIVER = `12`
| IMAGE_SUBSYSTEM_EFI_ROM = `13`
| IMAGE_SUBSYSTEM_XBOX = `14`
| IMAGE_FILE_MACHINE_UNKNOWN = `0`
| IMAGE_FILE_MACHINE_AM33 = `467`
| IMAGE_FILE_MACHINE_AMD64 = `34404`
| IMAGE_FILE_MACHINE_ARM = `448`
| IMAGE_FILE_MACHINE_EBC = `3772`
| IMAGE_FILE_MACHINE_I386 = `332`
| IMAGE_FILE_MACHINE_IA64 = `512`
| IMAGE_FILE_MACHINE_MR32 = `36929`
| IMAGE_FILE_MACHINE_MIPS16 = `614`
| IMAGE_FILE_MACHINE_MIPSFPU = `870`
| IMAGE_FILE_MACHINE_MIPSFPU16 = `1126`
| IMAGE_FILE_MACHINE_POWERPC = `496`
| IMAGE_FILE_MACHINE_POWERPCFP = `497`
| IMAGE_FILE_MACHINE_R4000 = `358`
| IMAGE_FILE_MACHINE_SH3 = `418`
| IMAGE_FILE_MACHINE_SH3DSP = `419`
| IMAGE_FILE_MACHINE_SH4 = `422`
| IMAGE_FILE_MACHINE_SH5 = `424`
| IMAGE_FILE_MACHINE_THUMB = `450`
| IMAGE_FILE_MACHINE_WCEMIPSV2 = `361`
| IMAGE_REL_BASED_ABSOLUTE = `0`
| IMAGE_REL_BASED_HIGH = `1`
| IMAGE_REL_BASED_LOW = `2`
| IMAGE_REL_BASED_HIGHLOW = `3`
| IMAGE_REL_BASED_HIGHADJ = `4`
| IMAGE_REL_BASED_MIPS_JMPADDR = `5`
| IMAGE_REL_BASED_SECTION = `6`
| IMAGE_REL_BASED_REL = `7`
| IMAGE_REL_BASED_MIPS_JMPADDR16 = `9`
| IMAGE_REL_BASED_IA64_IMM64 = `9`
| IMAGE_REL_BASED_DIR64 = `10`
| IMAGE_REL_BASED_HIGH3ADJ = `11`
| IMAGE_DLL_CHARACTERISTICS_RESERVED_0x0001 = `1`
| IMAGE_DLL_CHARACTERISTICS_RESERVED_0x0002 = `2`
| IMAGE_DLL_CHARACTERISTICS_RESERVED_0x0004 = `4`
| IMAGE_DLL_CHARACTERISTICS_RESERVED_0x0008 = `8`
| IMAGE_DLL_CHARACTERISTICS_DYNAMIC_BASE = `64`
| IMAGE_DLL_CHARACTERISTICS_FORCE_INTEGRITY = `128`
| IMAGE_DLL_CHARACTERISTICS_NX_COMPAT = `256`
| IMAGE_DLL_CHARACTERISTICS_NO_ISOLATION = `512`
| IMAGE_DLL_CHARACTERISTICS_NO_SEH = `1024`
| IMAGE_DLL_CHARACTERISTICS_NO_BIND = `2048`
| IMAGE_DLL_CHARACTERISTICS_RESERVED_0x1000 = `4096`
| IMAGE_DLL_CHARACTERISTICS_WDM_DRIVER = `8192`
| IMAGE_DLL_CHARACTERISTICS_TERMINAL_SERVER_AWARE = `32768`
| ADDRESS_MASK32 = `2147483647`
| ADDRESS_MASK64 = `9223372036854775807`
| RT_CURSOR = `1`
| RT_BITMAP = `2`
| RT_ICON = `3`
| RT_MENU = `4`
| RT_DIALOG = `5`
| RT_STRING = `6`
| RT_FONTDIR = `7`
| RT_FONT = `8`
| RT_ACCELERATOR = `9`
| RT_RCDATA = `10`
| RT_MESSAGETABLE = `11`
| RT_GROUP_CURSOR = `12`
| RT_GROUP_ICON = `14`
| RT_VERSION = `16`
| RT_DLGINCLUDE = `17`
| RT_PLUGPLAY = `19`
| RT_VXD = `20`
| RT_ANICURSOR = `21`
| RT_ANIICON = `22`
| RT_HTML = `23`
| RT_MANIFEST = `24`
| LANG_NEUTRAL = `0`
| LANG_INVARIANT = `127`
| LANG_AFRIKAANS = `54`
| LANG_ALBANIAN = `28`
| LANG_ARABIC = `1`
| LANG_ARMENIAN = `43`
| LANG_ASSAMESE = `77`
| LANG_AZERI = `44`
| LANG_BASQUE = `45`
| LANG_BELARUSIAN = `35`
| LANG_BENGALI = `69`
| LANG_BULGARIAN = `2`
| LANG_CATALAN = `3`
| LANG_CHINESE = `4`
| LANG_CROATIAN = `26`
| LANG_CZECH = `5`
| LANG_DANISH = `6`
| LANG_DIVEHI = `101`
| LANG_DUTCH = `19`
| LANG_ENGLISH = `9`
| LANG_ESTONIAN = `37`
| LANG_FAEROESE = `56`
| LANG_FARSI = `41`
| LANG_FINNISH = `11`
| LANG_FRENCH = `12`
| LANG_GALICIAN = `86`
| LANG_GEORGIAN = `55`
| LANG_GERMAN = `7`
| LANG_GREEK = `8`
| LANG_GUJARATI = `71`
| LANG_HEBREW = `13`
| LANG_HINDI = `57`
| LANG_HUNGARIAN = `14`
| LANG_ICELANDIC = `15`
| LANG_INDONESIAN = `33`
| LANG_ITALIAN = `16`
| LANG_JAPANESE = `17`
| LANG_KANNADA = `75`
| LANG_KASHMIRI = `96`
| LANG_KAZAK = `63`
| LANG_KONKANI = `87`
| LANG_KOREAN = `18`
| LANG_KYRGYZ = `64`
| LANG_LATVIAN = `38`
| LANG_LITHUANIAN = `39`
| LANG_MACEDONIAN = `47`
| LANG_MALAY = `62`
| LANG_MALAYALAM = `76`
| LANG_MANIPURI = `88`
| LANG_MARATHI = `78`
| LANG_MONGOLIAN = `80`
| LANG_NEPALI = `97`
| LANG_NORWEGIAN = `20`
| LANG_ORIYA = `72`
| LANG_POLISH = `21`
| LANG_PORTUGUESE = `22`
| LANG_PUNJABI = `70`
| LANG_ROMANIAN = `24`
| LANG_RUSSIAN = `25`
| LANG_SANSKRIT = `79`
| LANG_SERBIAN = `26`
| LANG_SINDHI = `89`
| LANG_SLOVAK = `27`
| LANG_SLOVENIAN = `36`
| LANG_SPANISH = `10`
| LANG_SWAHILI = `65`
| LANG_SWEDISH = `29`
| LANG_SYRIAC = `90`
| LANG_TAMIL = `73`
| LANG_TATAR = `68`
| LANG_TELUGU = `74`
| LANG_THAI = `30`
| LANG_TURKISH = `31`
| LANG_UKRAINIAN = `34`
| LANG_URDU = `32`
| LANG_UZBEK = `67`
| LANG_VIETNAMESE = `42`
| LANG_GAELIC = `60`
| LANG_MALTESE = `58`
| LANG_MAORI = `40`
| LANG_RHAETO_ROMANCE = `23`
| LANG_SAAMI = `59`
| LANG_SORBIAN = `46`
| LANG_SUTU = `48`
| LANG_TSONGA = `49`
| LANG_TSWANA = `50`
| LANG_VENDA = `51`
| LANG_XHOSA = `52`
| LANG_ZULU = `53`
| LANG_ESPERANTO = `143`
| LANG_WALON = `144`
| LANG_CORNISH = `145`
| LANG_WELSH = `146`
| LANG_BRETON = `147`
| SUBLANG_NEUTRAL = `0`
| SUBLANG_DEFAULT = `1`
| SUBLANG_SYS_DEFAULT = `2`
| SUBLANG_ARABIC_SAUDI_ARABIA = `1`
| SUBLANG_ARABIC_IRAQ = `2`
| SUBLANG_ARABIC_EGYPT = `3`
| SUBLANG_ARABIC_LIBYA = `4`
| SUBLANG_ARABIC_ALGERIA = `5`
| SUBLANG_ARABIC_MOROCCO = `6`
| SUBLANG_ARABIC_TUNISIA = `7`
| SUBLANG_ARABIC_OMAN = `8`
| SUBLANG_ARABIC_YEMEN = `9`
| SUBLANG_ARABIC_SYRIA = `10`
| SUBLANG_ARABIC_JORDAN = `11`
| SUBLANG_ARABIC_LEBANON = `12`
| SUBLANG_ARABIC_KUWAIT = `13`
| SUBLANG_ARABIC_UAE = `14`
| SUBLANG_ARABIC_BAHRAIN = `15`
| SUBLANG_ARABIC_QATAR = `16`
| SUBLANG_AZERI_LATIN = `1`
| SUBLANG_AZERI_CYRILLIC = `2`
| SUBLANG_CHINESE_TRADITIONAL = `1`
| SUBLANG_CHINESE_SIMPLIFIED = `2`
| SUBLANG_CHINESE_HONGKONG = `3`
| SUBLANG_CHINESE_SINGAPORE = `4`
| SUBLANG_CHINESE_MACAU = `5`
| SUBLANG_DUTCH = `1`
| SUBLANG_DUTCH_BELGIAN = `2`
| SUBLANG_ENGLISH_US = `1`
| SUBLANG_ENGLISH_UK = `2`
| SUBLANG_ENGLISH_AUS = `3`
| SUBLANG_ENGLISH_CAN = `4`
| SUBLANG_ENGLISH_NZ = `5`
| SUBLANG_ENGLISH_EIRE = `6`
| SUBLANG_ENGLISH_SOUTH_AFRICA = `7`
| SUBLANG_ENGLISH_JAMAICA = `8`
| SUBLANG_ENGLISH_CARIBBEAN = `9`
| SUBLANG_ENGLISH_BELIZE = `10`
| SUBLANG_ENGLISH_TRINIDAD = `11`
| SUBLANG_ENGLISH_ZIMBABWE = `12`
| SUBLANG_ENGLISH_PHILIPPINES = `13`
| SUBLANG_FRENCH = `1`
| SUBLANG_FRENCH_BELGIAN = `2`
| SUBLANG_FRENCH_CANADIAN = `3`
| SUBLANG_FRENCH_SWISS = `4`
| SUBLANG_FRENCH_LUXEMBOURG = `5`
| SUBLANG_FRENCH_MONACO = `6`
| SUBLANG_GERMAN = `1`
| SUBLANG_GERMAN_SWISS = `2`
| SUBLANG_GERMAN_AUSTRIAN = `3`
| SUBLANG_GERMAN_LUXEMBOURG = `4`
| SUBLANG_GERMAN_LIECHTENSTEIN = `5`
| SUBLANG_ITALIAN = `1`
| SUBLANG_ITALIAN_SWISS = `2`
| SUBLANG_KASHMIRI_SASIA = `2`
| SUBLANG_KASHMIRI_INDIA = `2`
| SUBLANG_KOREAN = `1`
| SUBLANG_LITHUANIAN = `1`
| SUBLANG_MALAY_MALAYSIA = `1`
| SUBLANG_MALAY_BRUNEI_DARUSSALAM = `2`
| SUBLANG_NEPALI_INDIA = `2`
| SUBLANG_NORWEGIAN_BOKMAL = `1`
| SUBLANG_NORWEGIAN_NYNORSK = `2`
| SUBLANG_PORTUGUESE = `2`
| SUBLANG_PORTUGUESE_BRAZILIAN = `1`
| SUBLANG_SERBIAN_LATIN = `2`
| SUBLANG_SERBIAN_CYRILLIC = `3`
| SUBLANG_SPANISH = `1`
| SUBLANG_SPANISH_MEXICAN = `2`
| SUBLANG_SPANISH_MODERN = `3`
| SUBLANG_SPANISH_GUATEMALA = `4`
| SUBLANG_SPANISH_COSTA_RICA = `5`
| SUBLANG_SPANISH_PANAMA = `6`
| SUBLANG_SPANISH_DOMINICAN_REPUBLIC = `7`
| SUBLANG_SPANISH_VENEZUELA = `8`
| SUBLANG_SPANISH_COLOMBIA = `9`
| SUBLANG_SPANISH_PERU = `10`
| SUBLANG_SPANISH_ARGENTINA = `11`
| SUBLANG_SPANISH_ECUADOR = `12`
| SUBLANG_SPANISH_CHILE = `13`
| SUBLANG_SPANISH_URUGUAY = `14`
| SUBLANG_SPANISH_PARAGUAY = `15`
| SUBLANG_SPANISH_BOLIVIA = `16`
| SUBLANG_SPANISH_EL_SALVADOR = `17`
| SUBLANG_SPANISH_HONDURAS = `18`
| SUBLANG_SPANISH_NICARAGUA = `19`
| SUBLANG_SPANISH_PUERTO_RICO = `20`
| SUBLANG_SWEDISH = `1`
| SUBLANG_SWEDISH_FINLAND = `2`
| SUBLANG_URDU_PAKISTAN = `1`
| SUBLANG_URDU_INDIA = `2`
| SUBLANG_UZBEK_LATIN = `1`
| SUBLANG_UZBEK_CYRILLIC = `2`
| SUBLANG_DUTCH_SURINAM = `3`
| SUBLANG_ROMANIAN = `1`
| SUBLANG_ROMANIAN_MOLDAVIA = `2`
| SUBLANG_RUSSIAN = `1`
| SUBLANG_RUSSIAN_MOLDAVIA = `2`
| SUBLANG_CROATIAN = `1`
| SUBLANG_LITHUANIAN_CLASSIC = `2`
| SUBLANG_GAELIC = `1`
| SUBLANG_GAELIC_SCOTTISH = `2`
| SUBLANG_GAELIC_MANX = `3`
| __package__ = `None` hash(x)